tlslite.FileObject.FileObject

Package tlslite :: Module FileObject :: Class FileObject |
[show private | hide private]
[frames | no frames]

## Class FileObject

This class provides a file object interface to a `tlslite.TLSConnection.TLSConnection`.

Call makefile() on a TLSConnection to create a FileObject instance.

This class was copied, with minor modifications, from the _fileobject class in socket.py. Note that fileno() is not implemented.

Method Summary
| `__init__(self, sock, mode, bufsize)`
| `__del__(self)`
| `__iter__(self)`
| `close(self)`
| `flush(self)`
| `next(self)`
| `read(self, size)`
| `readline(self, size)`
| `readlines(self, sizehint)`
| `write(self, data)`
| `writelines(self, list)`

Property Summary
| `closed`: True if the file is closed

Class Variable Summary
`int` | `default_bufsize` = 16384

Property Details

### closed True if the file is closed Get Method: `_getclosed`(self)

Class Variable Details

    ### default_bufsize Type: `int` Value:
        16384

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net